﻿using Microsoft.AspNetCore.Components;

namespace Connected.Components;
public partial class GlyphButton : Button
{
	#region Parameters

	/// <summary>
	/// Glyph (Icon) inside the button.
	/// Options: SVG string --> Icons
	/// Default: string.Empty
	/// </summary>
	[Parameter, EditorRequired]
	public string Glyph { get; set; } = string.Empty;

	/// <summary>
	/// Position of the glyph relative to button Text parameter. If Glyph parameter == string.Empty this parameter is ignored
	/// Options: Position.[left,top,right,bottom]
	/// Default: Position.left 
	/// </summary>
	[Parameter]
	public Position GlyphPosition { get; set; } = Position.Left;

	/// <summary>
	/// Color for the glyph. If Glyph parameter is empty this parameter is ignored
	/// Options: Color.[Core,Primary,Secondary,Success,Info,Warning,Danger,White,Light,Dark]
	/// Default: Color.Dark
	/// </summary>
	[Parameter]
	public Color GlyphColor { get; set; } = Color.Dark;

	#endregion

}
